==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/pl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Motyw o wysokim kontraście",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motyw o wysokim kontraście ułatwiający nawigację. Jakość obrazu jest zmniejszona, ale za to poprawiona przejrzystość.",
    "Dark theme (beta)" : "Ciemny motyw (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ciemny motyw, który łagodzi zmęczenie oczu, zmniejszając ogólną jasność. Nadal jest w fazie rozwoju, więc proszę zgłaszać wszelkie zauważone błędy.",
    "Dyslexia font" : "Czcionka dysleksji",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów odczytu spowodowanych dysleksją.",
    "Accessibility" : "Dostępność",
    "Accessibility options for nextcloud" : "Opcje dostępności dla Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Zapewnia wiele opcji dostępu, aby ułatwić korzystanie z Nextcloud",
    "Web Content Accessibility Guidelines" : "Wytyczne Dotyczące Dostępności Treści Internetowych",
    "our issue tracker" : "nasz tracker do błędów",
    "our design team" : "nasz zespół projektowy",
    "Enable" : "Włącz"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/pl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Motyw o wysokim kontraście",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motyw o wysokim kontraście ułatwiający nawigację. Jakość obrazu jest zmniejszona, ale za to poprawiona przejrzystość.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ciemny motyw, który łagodzi zmęczenie oczu, zmniejszając ogólną jasność. Nadal jest w fazie rozwoju, więc proszę zgłaszać wszelkie zauważone błędy.",
    "Dyslexia font" : "Czcionki dysleksji",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów odczytu spowodowanych dysleksją.",
    "Accessibility" : "Dostępność",
    "Accessibility options for nextcloud" : "Opcje dostępności dla Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Zapewnia wiele opcji dostępu, aby ułatwić korzystanie z Nextcloud",
    "Web Content Accessibility Guidelines" : "Web Content Accessibility Guidelines",
    "our issue tracker" : "na listę błędów",
    "our design team" : "naszego zespołu projektowego",
    "Enable" : "Włącz",
    "Dark theme (beta)" : "Ciemny motyw (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic to darmowa czcionka zaprojektowana w celu zmniejszenia niektórych typowych błędów odczytu spowodowanych dysleksją. Czcionka została stworzona przez Abelardo Gonzaleza, który wydał ją na licencji open source.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Zapewnia wiele opcji dostępu, aby ułatwić korzystanie z Nextcloud",
    "Themes" : "Motyw",
    "Fonts" : "Czcionki",
    "enabled" : "włączone"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
